@@ -154,7 +154,9 @@ handle_have_type (AudioPlay *play)
 {
 	AudioPlayPriv *priv = play->priv;
 	GstCaps *caps = priv->caps;
-	gchar *mime = g_strdup_printf (gst_caps_get_mime (caps));
+//	gchar *mime = g_strdup_printf (gst_caps_get_mime (caps));
+//	FIXME
+        gchar *mime = g_strdup ("unknown");
 	GstElement *decoder = NULL;
 
 #ifdef DEBUG
@@ -341,12 +343,14 @@ deep_notify (GObject *object, GstObject *origin,
 		g_value_init (&value, pspec->value_type);
 		g_object_get_property (G_OBJECT (origin), pspec->name, &value);
 		play->priv->caps = g_value_peek_pointer (&value);
+#if 0
 		if (gst_caps_get_props (play->priv->caps) == NULL)
 		{
 			NM_DEBUG("no caps yet, returning\n");
 		}
 		else
 			play->priv->have_caps = TRUE;
+#endif
 	}
 	if (strcmp (pspec->name, "channels") == 0)
 	{
@@ -706,7 +710,7 @@ audio_play_update_length (AudioPlay *play)
 	}
 	caps = gst_pad_get_caps (pad);
 	if (caps == NULL) g_print ("WARNING: caps are NULL\n");
-	gst_caps_debug (caps, "caps of decoder src pad");
+	//gst_caps_debug (caps, "caps of decoder src pad");
 
 	res = gst_pad_query (pad, GST_QUERY_TOTAL, &format, &value);
 	if (!res) 
